@@ -5,11 +5,23 @@ NULL
 #' than divs, for example, this seems to be the only way to center a block).
 #'
 #' @noRd
-panel <- function(..., width = "100%", outer_align = NULL, inner_align = NULL,
-  padding = NULL, margin = NULL, outer_class = NULL, inner_class = NULL,
-  background_color = NULL, max_width = NULL) {
+panel <- function(
+    ...,
+    width = "100%",
+    outer_align = NULL,
+    inner_align = NULL,
+    padding = NULL,
+    margin = NULL,
+    outer_class = NULL,
+    inner_class = NULL,
+    background_color = NULL,
+    max_width = NULL
+) {
 
-  tags$table(width = width, align = outer_align, class = outer_class,
+  tags$table(
+    width = width,
+    align = outer_align,
+    class = outer_class,
     style = css(
       margin = margin,
       background_color = background_color,
