@@ -10,7 +10,7 @@ test_that("The `create_rmd_preview_message()` function works properly", {
       paste0(
         "^<div style=\"text-align: center; background:#fcfcfc\">",
         "<h2 style=\"margin-bottom: 0; padding-bottom: 0;\">",
-        "This is an email preview for RStudio Connect</h2>",
+        "This is an email preview for Posit Connect</h2>",
         "<p style=\"text-align: center; background:#fcfcfc; padding-top: 0;.*?",
         "</span></strong>Connect test message<br></p><hr></div>$"
       )
